@@ -25,8 +25,7 @@ class Elastic:
             self.es.index(index="logs-" + '{0:%Y-%m-%d}'.format(datetime.now()), doc_type="_doc", document=body)
             pass
         except Exception as e:
-            print("Elasticsearch unavailable")
-            print("An exception occurred [" + jsonpickle.encode(e) + " ]")
+            print("Elasticsearch unavailable: An exception occurred [", e, "]")
             pass
 
     def async_post(self, severity, message, args):
@@ -67,7 +66,7 @@ class Logger:
     def logger(self, level, message, *args):
         args_message = ''
 
-        if args:
+        if args or (len(args) == 1 and args[0] == ()):
             args = jsonpickle.encode(args)
             args_message = " - args:[ " + args + " ]"
 
